Index: pkg/analysis_server/lib/src/services/index/index_store.dart |
diff --git a/pkg/analysis_server/lib/src/services/index/index_store.dart b/pkg/analysis_server/lib/src/services/index/index_store.dart |
index 858d0ac1b02fcac4108b32823e5a5c511ed34705..2b8dc2273b63d6368a4e86feb8da698017255002 100644 |
--- a/pkg/analysis_server/lib/src/services/index/index_store.dart |
+++ b/pkg/analysis_server/lib/src/services/index/index_store.dart |
@@ -20,48 +20,27 @@ abstract class InternalIndexStore extends IndexStore { |
String get statistics; |
/** |
- * Notifies the index store that we are going to index an unit with the given |
- * [unitElement]. |
- * |
- * If the unit is a part of a library, then all its locations are removed. |
- * |
- * If it is a defining compilation unit of a library, then index store also |
- * checks if some previously indexed parts of the library are not parts of the |
- * library anymore, and clears their information. |
- * |
- * [context] - the [AnalysisContext] in which unit being indexed. |
- * [unitElement] - the element of the unit being indexed. |
- * |
- * Returns `true` if the given [unitElement] may be indexed, or `false` if |
- * belongs to a disposed [AnalysisContext], is not resolved completely, etc. |
- */ |
- bool aboutToIndexDart( |
- AnalysisContext context, CompilationUnitElement unitElement); |
- |
- /** |
- * Notifies the index store that we are going to index an unit with the given |
- * [htmlElement]. |
+ * Notifies the index store that we are going to index the given [object]. |
* |
* [context] - the [AnalysisContext] in which unit being indexed. |
- * [htmlElement] - the [HtmlElement] being indexed. |
+ * [object] - the object being indexed. |
* |
* Returns `true` if the given [htmlElement] may be indexed, or `false` if |
* belongs to a disposed [AnalysisContext], is not resolved completely, etc. |
*/ |
- bool aboutToIndexHtml(AnalysisContext context, HtmlElement htmlElement); |
+ bool aboutToIndex(AnalysisContext context, Object object); |
/** |
- * Notifies the index store that there was an error during the current Dart |
+ * Notifies the index store that there was an error during the current |
* indexing, and all the information recorded after the last |
* [aboutToIndexDart] invocation must be discarded. |
*/ |
- void cancelIndexDart(); |
+ void cancelIndex(); |
/** |
* Notifies the index store that the current Dart or HTML unit indexing is |
* done. |
* |
- * If this method is not invoked after corresponding "aboutToIndex*" |
+ * If this method is not invoked after corresponding [aboutToIndex] |
* invocation, all recorded information may be lost. |
*/ |
void doneIndex(); |
@@ -20,48 +20,27 @@ abstract class InternalIndexStore extends IndexStore { |
* |
- * Returns `true` if the given [htmlElement] may be indexed, or `false` if |
+ * Returns `true` if the given [object] may be indexed, or `false` if |
* belongs to a disposed [AnalysisContext], is not resolved completely, etc. |
*/ |
@@ -20,48 +20,27 @@ abstract class InternalIndexStore extends IndexStore { |
* indexing, and all the information recorded after the last |
- * [aboutToIndexDart] invocation must be discarded. |
+ * [aboutToIndex] invocation must be discarded. |
*/ |
@@ -20,48 +20,27 @@ abstract class InternalIndexStore extends IndexStore { |
/** |
- * Notifies the index store that the current Dart or HTML unit indexing is |
- * done. |
+ * Notifies the index store that the current object indexing is done. |
* |